package com.cnblogs.seewood.s01;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Session;
import org.jbpm.JbpmConfiguration;
import org.jbpm.JbpmContext;

import junit.framework.TestCase;

public class ConfigurationTests extends TestCase {
	private final Log logger = LogFactory.getLog(this.getClass());
	
	public void testSimpleProcessInMemory() {
		JbpmConfiguration cfg;
/*
		// 载入配置的方法有很多，这里仅举几个常见例子
		// JbpmConfiguration构造时，会先载入
		// classpath:org/jbpm/default.jbpm.cfg.xml中的配置，
		// 然后根据用户指定位置载入配置信息
		// 用户自定义配置信息将会覆盖default.jbpm.cfg.xml的内容。
		// 默认配置读取classpath:hiberante.cfg.xml
		
		// 默认名称的载入配置，即classpath:jbpm.cfg.xml，
		cfg = JbpmConfiguration.getInstance();
		
		// 先载入classpath:org/jbpm/default.jbpm.cfg.xml中的配置
		// 再从指定名称的载入配置
		cfg = JbpmConfiguration.getInstance("jbpm-cfg.xml");
		
		// 从XML字符串构造配置
		cfg = JbpmConfiguration.parseXmlString(
				"<jbpm-configuration>" +
				"	<string name=\"resource.hibernate.cfg.xml\" " +
				"		value=\"cn/horncomb/bpm/jbpm/hibernate.cfg.xml\" />" +
				"</jbpm-configuration>");
*/
		// Spring测试类，默认采用Auto-wire，即从ApplicationContext中获取名称匹配的bean，
		// 自动注入。jbpmConfiguration就会自动注入的。
		// applicationContext-jbpm.xml 中定义了bean: jbpmConfiguration.
		
		cfg = JbpmConfiguration.getInstance("com/cnblogs/seewood/s01/jbpm.cfg.xml");
		assertNotNull(cfg);
		this.logger.info("成功创建Jbpm配置信息");
		
		JbpmContext ctx = cfg.createJbpmContext();
		assertNotNull(ctx);
		this.logger.info("成功创建JbpmContext");
		
		// 注意日志的输入，当第一次获取session的时候才初始化hibernate的配置。
		Session s = ctx.getSession();
		assertNotNull(s);
		this.logger.info("成功创建Hibernate Session");
		
		// 以后获取时，hibernate不会需要再初始化，所以这种情况用spring就更好了
		ctx.getSession();
		this.logger.info("再次获取Session");
	}
}
