package com.cnblogs.seewood.s02;

import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.jbpm.JbpmConfiguration;
import org.jbpm.JbpmContext;
import org.springframework.test.AbstractTransactionalDataSourceSpringContextTests;

/**
 * 简单流程测试
 * @author seewood
 * @version $LastChangedRevision$
 */
public class ConfigurationSpringTests
		extends AbstractTransactionalDataSourceSpringContextTests {
	private JbpmConfiguration jbpmConfiguration;
	private SessionFactory sessionFactory;

	@Override
	protected String getConfigPath() {
		// 返回配置文件路径(相对与classpath)
		return "/applicationContext.xml";
	}

	@Override
	protected boolean isRollback() {
		// 默认为true，即是测试完毕后事务全部rollback
		return super.isRollback();
	}

	public void testInitJbpmConfiguration() {
		JbpmConfiguration cfg;
		// Spring测试类，默认采用Auto-wire，即从ApplicationContext中获取名称匹配的bean，
		// 自动注入。jbpmConfiguration就会自动注入的。
		// applicationContext-jbpm.xml 中定义了bean: jbpmConfiguration.
		// 这是自定义的一个JbpmConfiguration的Factory Bean。
		cfg = this.getJbpmConfiguration();
		assertNotNull(cfg);
		this.logger.info("成功创建Jbpm配置信息");

		JbpmContext ctx = cfg.createJbpmContext();
		assertNotNull(ctx);
		this.logger.info("成功创建JbpmContext");

		// 注意与不使用Spring时候的区别
		// Spring已经初始化Hibernate配置了，所以这个时候不能使用ctx直接获取session
		// 而必须使用Spring中配置的工厂来获取session。
		// 后面会演示在web时，在哪里处理这个session问题比较好。

		// 使用Spring的session工厂
		ctx.setSessionFactory(this.sessionFactory);
		Session s = ctx.getSession();
		assertNotNull(s);
		this.logger.info("成功创建Hibernate Session");
	}

	public void testInitProcessDefinitionXml() {

	}

	public JbpmConfiguration getJbpmConfiguration() {
		return jbpmConfiguration;
	}

	public void setJbpmConfiguration(JbpmConfiguration jbpmConfiguration) {
		this.jbpmConfiguration = jbpmConfiguration;
	}

	public SessionFactory getSessionFactory() {
		return sessionFactory;
	}

	public void setSessionFactory(SessionFactory sessionFactory) {
		this.sessionFactory = sessionFactory;
	}
}
